@@ -66,20 +66,20 @@ paired_test_categorical <- function(tab) {
     tab <- as.table(tab)
   }
 
-  rowcounts <- tab %*% rep(1, ncol(tab))
-  tab <- tab[rowcounts > 0, ]
+  rowcounts <- tab %*% rep(1L, ncol(tab))
+  tab <- tab[rowcounts > 0L, ]
   if (!is_proper_matrix(tab)) return(empty_h_test())
 
   # due = McNemar ---------------------------------------------------
 
-  if (nrow(tab) == 2 && ncol(tab) == 2) {
+  if (nrow(tab) == 2L && ncol(tab) == 2L) {
     mn_test <- stats::mcnemar.test(tab)
 
     return(list(
       # values (mandatory)
-      P = mn_test$p.value,
-      stat = mn_test$statistic,
-      df = mn_test$parameter,
+      P = mn_test[["p.value"]],
+      stat = mn_test[["statistic"]],
+      df = mn_test[["parameter"]],
 
       # names (mandatory)
       testname = "McNemar",
@@ -105,11 +105,11 @@ paired_test_categorical <- function(tab) {
 
   tab_df <- dplyr::as_tibble(tab) %>%
     dplyr::mutate(
-      lev_id = lev_id[.data$var_levels],
-      group_id = group_id[.data$grouping_var]
+      lev_id = lev_id[.data[["var_levels"]]],
+      group_id = group_id[.data[["grouping_var"]]]
     ) %>%
-    dplyr::group_by(.data$grouping_var) %>%
-    dplyr::mutate(prop = .data$n / sum(.data$n)) %>%
+    dplyr::group_by(.data[["grouping_var"]]) %>%
+    dplyr::mutate(prop = .data[["n"]] / sum(.data[["n"]])) %>%
     dplyr::ungroup()
 
     st <- rms::Glm(
@@ -118,9 +118,9 @@ paired_test_categorical <- function(tab) {
       family = "quasibinomial"
     )
     cof <- stats::coef(st)
-    df <- st$rank - (names(cof)[1] == "Intercept")
-    lr <- st$null.deviance - st$deviance
-    pval <- 1 - stats::pchisq(lr, df)
+    df <- st[["rank"]] - (names(cof)[[1L]] == "Intercept")
+    lr <- st[["null.deviance"]] - st[["deviance"]]
+    pval <- 1L - stats::pchisq(lr, df)
 
   list(
     # values (mandatory)
